.. project-template documentation master file, created by
   sphinx-quickstart on Mon Jan 18 14:44:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##########
User guide
##########

What is ElPiGraph ?
=============================

Elastic Principal Graphs is a method for manifold learning and dimensionality reduction that summarizes datasets by fitting a principal graph in the middle of the data point cloud

Organization of `elpigraph-python`
==================================

WIP